@@ -21,6 +21,7 @@ import traceback
 
 #
 from wwpdb.utils.config.ConfigInfo import ConfigInfo, getSiteId
+from wwpdb.utils.config.ConfigInfoApp import ConfigInfoAppCommon
 from wwpdb.utils.dp.RcsbDpUtility import RcsbDpUtility  # pylint: disable=no-name-in-module,import-error
 from wwpdb.utils.db.SqlLoader import SqlLoader
 
@@ -28,19 +29,18 @@ from wwpdb.utils.db.SqlLoader import SqlLoader
 
 
 class DbLoadingApi(object):
-    """"""
+    """ """
 
     def __init__(self, log=sys.stderr, verbose=False):
-        """"""
+        """ """
         self.__lfh = log
         self.__verbose = verbose
         self.__debug = True
         self.__siteId = getSiteId()
         cI = ConfigInfo()
-        self.__pyPath = cI.get("SITE_PYTHON_SOURCE_PATH")
-        self.__pkgPath = cI.get("SITE_PACKAGES_PATH")
-        self.__schemaPath = cI.get("SITE_DA_INTERNAL_SCHEMA_PATH")
-        self.__dbServer = cI.get("SITE_DB_SERVER")
+        cIcommon = ConfigInfoAppCommon(self.__siteId)
+        self.__pkgPath = cIcommon.get_site_packages_path()
+        self.__schemaPath = cIcommon.get_site_da_internal_schema_path()
         self.__dbHost = cI.get("SITE_DB_HOST_NAME")
         self.__dbUser = cI.get("SITE_DB_USER_NAME")
         self.__dbPw = cI.get("SITE_DB_PASSWORD")
@@ -50,8 +50,8 @@ class DbLoadingApi(object):
 
         self.__dbName = "da_internal"
         self.__workPath = os.path.join(self.__archivePath, "archive")
-        self.__mysql = "/usr/bin/mysql "
-        self.__dbLoader = os.path.join(self.__pkgPath, "dbloader", "bin", "db-loader")
+        self.__mysql = "mysql "
+        self.__dbLoader = cIcommon.get_db_loader_path()
 
         self.__mapping = self.__schemaPath
 
@@ -206,82 +206,82 @@ class DbLoadingApi(object):
             traceback.print_exc(file=self.__lfh)
             return False
 
-    def XXXdoLoadStatus(self, pdbxFilePath, sessionDir):
-        """
-        Load the input file into the status database and session directory as input
+    # def XXXdoLoadStatus(self, pdbxFilePath, sessionDir):
+    #     """
+    #     Load the input file into the status database and session directory as input
 
-        """
-        # signal.signal(signal.SIGPIPE, signal.SIG_DFL)
-        self.__lfh.write("DbLoadingApi::doLoadStatus(): starting with file %s and session %s\n" % (pdbxFilePath, sessionDir))
-        try:
-            if os.path.exists(pdbxFilePath):
-                dataDir = sessionDir + "/" + self.__workDir
-                log1 = "db-loader.log"
-                if not os.path.exists(dataDir):
-                    print("Creating " + dataDir)
-                    os.makedirs(dataDir)
+    #     """
+    #     # signal.signal(signal.SIGPIPE, signal.SIG_DFL)
+    #     self.__lfh.write("DbLoadingApi::doLoadStatus(): starting with file %s and session %s\n" % (pdbxFilePath, sessionDir))
+    #     try:
+    #         if os.path.exists(pdbxFilePath):
+    #             dataDir = sessionDir + "/" + self.__workDir
+    #             log1 = "db-loader.log"
+    #             if not os.path.exists(dataDir):
+    #                 print("Creating " + dataDir)
+    #                 os.makedirs(dataDir)
 
-                cmd = "cd " + dataDir
-                cmd += "; " + self.__dbLoader + " -server mysql -f " + pdbxFilePath + " -map " + self.__mapping + " -db " + self.__dbName + " >& " + log1
-                os.system(cmd)
-                if self.__debug:
-                    self.__lfh.write("DbLoadingApi::doLoadStatus(): db-loader command %s\n" % cmd)
+    #             cmd = "cd " + dataDir
+    #             cmd += "; " + self.__dbLoader + " -server mysql -f " + pdbxFilePath + " -map " + self.__mapping + " -db " + self.__dbName + " >& " + log1
+    #             os.system(cmd)
+    #             if self.__debug:
+    #                 self.__lfh.write("DbLoadingApi::doLoadStatus(): db-loader command %s\n" % cmd)
 
-                file1 = os.path.join(dataDir, "DB_LOADER.sql")
-                log2 = os.path.join(dataDir, "status_load.log")
-                if os.path.exists(file1):
-                    cmd = "cd " + dataDir
-                    if self.__dbSocket is None:
-                        cmd += "; " + self.__mysql + "-u " + self.__dbUser + " -p" + self.__dbPw + " -h " + self.__dbHost + " -P " + self.__dbPort + " <" + file1 + " >& " + log2
-                    else:
-                        cmd += (
-                            "; "
-                            + self.__mysql
-                            + "-u "
-                            + self.__dbUser
-                            + " -p"
-                            + self.__dbPw
-                            + " -h "
-                            + self.__dbHost
-                            + " -P "
-                            + self.__dbPort
-                            + " -S "
-                            + self.__dbSocket
-                            + " <"
-                            + file1
-                            + " >& "
-                            + log2
-                        )  # noqa: E501
-                    if self.__debug:
-                        self.__lfh.write("DbLoadingApi::doLoadStatus(): database server command %s\n" % cmd)
-                    os.system(cmd)
-                    if os.path.exists(log2):
-                        file = open(log2, "r")
-                        for line in file:
-                            for word in line.split():
-                                if word.upper() == "ERROR":
-                                    self.__lfh.write("DbLoadingApi::doLoadStatus(): ERROR found during the database loading. Please check the log file " + log2 + " for details.\n")
-                                    return False
-                    else:
-                        self.__lfh.write(
-                            'DbLoadingApi::doLoadStatus(): db-loader didn\'t generate the data file "DB_LOADER.sql". Please check the log file '
-                            + os.path.join(dataDir, log1)
-                            + " for details.\n"
-                        )
+    #             file1 = os.path.join(dataDir, "DB_LOADER.sql")
+    #             log2 = os.path.join(dataDir, "status_load.log")
+    #             if os.path.exists(file1):
+    #                 cmd = "cd " + dataDir
+    #                 if self.__dbSocket is None:
+    #                     cmd += "; " + self.__mysql + "-u " + self.__dbUser + " -p" + self.__dbPw + " -h " + self.__dbHost + " -P " + self.__dbPort + " <" + file1 + " >& " + log2
+    #                 else:
+    #                     cmd += (
+    #                         "; "
+    #                         + self.__mysql
+    #                         + "-u "
+    #                         + self.__dbUser
+    #                         + " -p"
+    #                         + self.__dbPw
+    #                         + " -h "
+    #                         + self.__dbHost
+    #                         + " -P "
+    #                         + self.__dbPort
+    #                         + " -S "
+    #                         + self.__dbSocket
+    #                         + " <"
+    #                         + file1
+    #                         + " >& "
+    #                         + log2
+    #                     )  # noqa: E501
+    #                 if self.__debug:
+    #                     self.__lfh.write("DbLoadingApi::doLoadStatus(): database server command %s\n" % cmd)
+    #                 os.system(cmd)
+    #                 if os.path.exists(log2):
+    #                     file = open(log2, "r")
+    #                     for line in file:
+    #                         for word in line.split():
+    #                             if word.upper() == "ERROR":
+    #                                 self.__lfh.write("DbLoadingApi::doLoadStatus(): ERROR found during the database loading. Please check the log file " + log2 + " for details.\n")
+    #                                 return False
+    #                 else:
+    #                     self.__lfh.write(
+    #                         'DbLoadingApi::doLoadStatus(): db-loader didn\'t generate the data file "DB_LOADER.sql". Please check the log file '
+    #                         + os.path.join(dataDir, log1)
+    #                         + " for details.\n"
+    #                     )
 
-                    #
-                    self.__lfh.write("DbLoadingApi::doLoadStatus(): completed\n")
-                    return True
-                else:
-                    self.__lfh.write("DbLoadingApi::doLoadStatus(): failing, no load file created.\n")
-                    return False
-            else:
-                self.__lfh.write("DbLoadingApi::doLoadStatus(): failing, no input cif file found.\n")
-                return False
-        except:  # noqa: E722 pylint: disable=bare-except
-            self.__lfh.write("DbLoadingApi::doLoadStatus(): failing, with exception.\n")
-            traceback.print_exc(file=self.__lfh)
-            return False
+    #                 #
+    #                 self.__lfh.write("DbLoadingApi::doLoadStatus(): completed\n")
+    #                 return True
+    #             else:
+    #                 self.__lfh.write("DbLoadingApi::doLoadStatus(): failing, no load file created.\n")
+    #                 return False
+    #         else:
+    #             self.__lfh.write("DbLoadingApi::doLoadStatus(): failing, no input cif file found.\n")
+    #             return False
+    #     except:  # noqa: E722 pylint: disable=bare-except
+    #         self.__lfh.write("DbLoadingApi::doLoadStatus(): failing, with exception.\n")
+    #         traceback.print_exc(file=self.__lfh)
+    #         return False
 
     def doDataLoadingBcp(self, depId, sessionDir):
         """
